import math
import time
import asyncio

from pyrogram.types import InlineKeyboardButton, InlineKeyboardMarkup
from pyrogram.errors import UserBannedInChannel, UserNotParticipant


#Forcesub
async def force_sub(c, m, channel, ft):
    try:
        CHANNEL = channel
        chat = await c.get_chat_member(CHANNEL, m.from_user.id)
        if chat.status=='kicked':
            await m.reply_text('**Sorry Sir, You are Banned to use me. Contact my [Support Group](https://t.me/DKBOTZSUPPORT).**')
            return True

    except UserNotParticipant:
        button = [[InlineKeyboardButton('🔰 Join Now 🔰', url=f'https://t.me/{CHANNEL}')]]
        markup = InlineKeyboardMarkup(button)
        await m.reply_text(text=f"👋 Hi {m.from_user.mention(style='md')},\n\n{ft}", reply_markup=markup, disable_web_page_preview=True)
        return True

    except Exception as e:
        await m.reply_text(f"Some thing went wrong 🤔. Try Again And if Same issue Comes Then Contact [Our Support Group](https://t.me/DKBOTZSUPPORT)\n\nError :- {e}", disable_web_page_preview=True)
        return True

#Forcesub
async def force_subs(c, m, channel, ft):
    try:
        CHANNEL = channel
        chat = await c.get_chat_member(CHANNEL, m.from_user.id)
        if chat.status=='kicked':
            await m.reply_text('**Sorry Sir, You are Banned to use me. Contact my [Support Group](https://t.me/DKBOTZSUPPORT).**')
            return True

    except UserNotParticipant:
        button = [[InlineKeyboardButton('🔰 Join Now 🔰', url=f'https://t.me/{CHANNEL}')]]
        markup = InlineKeyboardMarkup(button)
        await m.reply_text(text=f"👋 Hi {m.from_user.mention(style='md')},\n\n{ft}\n\nAnd Also Join :- @DKBOTZ", reply_markup=markup, disable_web_page_preview=True)
        return True

    except Exception as e:
        await m.reply_text(f"Some thing went wrong 🤔. Try Again And if Same issue Comes Then Contact [Our Support Group](https://t.me/DKBOTZSUPPORT)\n\nError :- {e}", disable_web_page_preview=True)
        return True



import requests, re, random
 
from os import environ

API_KEY = (environ.get('API_KEY', '17907303 2808129d')).split()

def get_movie_info(movieTitle):
    url = 'http://www.omdbapi.com'
    api_key = random.choice(API_KEY)
    data = {'apikey':api_key,'t':movieTitle}
    response = requests.get(url,data).json()

    if response.get("Response") != "True":
        return None

    movie_info = {}
    movie_info["title"] = response.get("Title")
    movie_info["year"] = response.get("Year")
    movie_info["release"] = response.get("Released")
    movie_info["duration"] = response.get("Runtime")
    movie_info["genre"] = response.get("Genre")
    movie_info["director"] = response.get("Director")
    movie_info["writer"] = response.get("Writer")
    movie_info["actors"] = response.get("Actors")
    movie_info["plot"] = response.get("Plot")
    movie_info["language"] = response.get("Language")
    movie_info["country"] = response.get("Country")
    movie_info["Writer"] = response.get("Writer")
    movie_info["BoxOffice"] = response.get("BoxOffice")
    movie_info["country"] = response.get("Country")
    movie_info["ratings"] = response.get("Ratings")
    movie_info["imdb_rating"] = response.get("imdbRating")
    movie_info["votes"] = response.get("imdbVotes")
    movie_info["imdb_id"] = response.get("imdbID")
    movie_info["pimage"] = response.get("Poster")

    return movie_info



# Bot By https://t.me/DKBOTZ || https://t.me/DK_BOTZ || https://t.me/DKBOTZHELP
# Creadit To My Friend https://t.me/Bot_Magic_World


import requests
import re, random, asyncio 
from os import environ
from .imdb import get_movie_info
from mdiskpro import MdiskPro
from pyrogram import Client, filters
from pyrogram.types import InlineKeyboardMarkup, InlineKeyboardButton, CallbackQuery

PICS = (environ.get('PICS', 'https://telegra.ph/file/7e56d907542396289fee4.jpg https://telegra.ph/file/9aa8dd372f4739fe02d85.jpg https://telegra.ph/file/adffc5ce502f5578e2806.jpg https://telegra.ph/file/6937b60bc2617597b92fd.jpg https://telegra.ph/file/09a7abaab340143f9c7e7.jpg https://telegra.ph/file/5a82c4a59bd04d415af1c.jpg https://telegra.ph/file/323986d3bd9c4c1b3cb26.jpg https://telegra.ph/file/b8a82dcb89fb296f92ca0.jpg https://telegra.ph/file/31adab039a85ed88e22b0.jpg https://telegra.ph/file/c0e0f4c3ed53ac8438f34.jpg https://telegra.ph/file/eede835fb3c37e07c9cee.jpg https://telegra.ph/file/e17d2d068f71a9867d554.jpg https://telegra.ph/file/8fb1ae7d995e8735a7c25.jpg https://telegra.ph/file/8fed19586b4aa019ec215.jpg https://telegra.ph/file/8e6c923abd6139083e1de.jpg https://telegra.ph/file/0049d801d29e83d68b001.jpg')).split()

FILTER_DEL_SECOND = 10000
API_KEY = 'True'

MOVIE_TEXTZ = """
🔎 **Requested By:** {mention}\n**⌛ Requested Name:** {query}\n ©️ {group_name}"""

async def group_filters(client, update, temp, get_filter_results, get_size, split_list, get_settings, caption_text):
    if re.findall("((^\/|^,|^!|^\.|^[\U0001F600-\U000E007F]).*)", update.text):
        return
    if 2 < len(update.text) < 100:    
        btn = []
        search = update.text
        settings = await get_settings(update.chat.id)
        MOVIE_TEXT = settings["template"]
        files = await get_filter_results(query=search)
        if not files:
            if settings["spellmode"]:
                try:
                    reply = search.replace(" ", '+')  
                    buttons = [[ InlineKeyboardButton("🔍 𝚂𝙴𝙰𝚁𝙲𝙷 𝚃𝙾 𝙶𝙾𝙾𝙶𝙻𝙴 🔎", url=f"https://www.google.com/search?q={reply}") ],[ InlineKeyboardButton("× 𝙲𝙻𝙾𝚂𝙴 ×", callback_data="close") ]]
                    spell = await update.reply_text(text=settings["spelltext"].format(query=search, first_name=update.from_user.first_name, last_name=update.from_user.last_name, title=update.chat.title, mention=update.from_user.mention), disable_web_page_preview=True, reply_markup=InlineKeyboardMarkup(buttons))           
                    await asyncio.sleep(60)
                    await spell.delete()
                except:
                    pass
            return
        if files:
            for file in files:
                file_id = file.file_id
                filesize = f"[{get_size(file.file_size)}]"
                filename = f"{file.file_name}"
                settings = await get_settings(update.chat.id)
                API = settings["api"] if settings["api"] else 'cbd63775f798fe0e58c67a56e6ce8b70c495cda4' # Shareus :- UsdyUrWdP9Mt2tPbxTVSbsfM4hu2 

                if settings["button"]:
                    btn.append([InlineKeyboardButton(f"{filesize} {filename}", callback_data=f'DKBOTZGP#{file_id}')])
                else:                    
                    btn.append([InlineKeyboardButton(f"{filesize}", callback_data=f'DKBOTZGP#{file_id}'),
                                InlineKeyboardButton(f"{filename}", callback_data=f'DKBOTZGP#{file_id}')])
        else:
            return

        if not btn:
            return

        if len(btn) > temp.filterBtns: 
            btns = list(split_list(btn, temp.filterBtns)) 
            keyword = f"{update.chat.id}-{update.id}"
            temp.BUTTONS[keyword] = {
                "total" : len(btns),
                "buttons" : btns
            }
        else:
            buttons = btn
            buttons.append([InlineKeyboardButton("📃 Pages 1/1",callback_data="pages"),
                            InlineKeyboardButton("Close 🗑️", callback_data="close")])

            buttons.append([InlineKeyboardButton("🤖 𝙲𝙷𝙴𝙲𝙺 𝙼𝚈 𝙿𝙼 🤖", url=f"https://telegram.dog/{temp.Bot_Username}?")])

            try:             
                if settings["photo"]:
                    movie_name = update.text
                    movie_info = get_movie_info(movie_name)
                    if movie_info:
                        poster = movie_info["pimage"]
                    
    
                    try:
                        query = search
                        movie_title = movie_info['title']
                        Rating = movie_info['imdb_rating']
                        Year = movie_info['release']
                        Genres = movie_info['genre']
                        Runtime = movie_info['duration']
                        Countries = movie_info['country']
                        director = movie_info['director']
                        writer = movie_info['writer']
                        BoxOffice = movie_info['BoxOffice']
                        language = movie_info['language']
                        votes = movie_info['votes']
                        mention = update.from_user.mention
                        greeting = None
                        remove = await update.reply_photo(photo=poster, caption=f"**👨‍🦱 Requested By:** {mention}\n\n**🤵‍♂️ Requested Name:** {query}\n\n🎥 **Movie Title:** {movie_title}\n\n🎭 **Genres:** {Genres}\n\n**📀 Votes:** {votes}\n\n🌟 **IMDB Rating :** {Rating}\n\n📆 **Released:**  {Year} \n\n📣 **BoxOffice:** {BoxOffice}\n\n**🧑‍💻 Writer:** {writer}\n\n**🕺 Director:** {director}\n\n🗺️ **Countries:** {Countries}\n\n{caption_text}", reply_markup=InlineKeyboardMarkup(buttons))
                        await asyncio.sleep(FILTER_DEL_SECOND)
                        await remove.delete()
                    except:
                        remove = await update.reply_photo(photo=random.choice(PICS), caption=f"**👨‍🦱 Requested By:** {mention}\n\n**🤵‍♂️ Requested Name:** {query}\n\n🎥 **Movie Title:** {movie_title}\n\n🎭 **Genres:** {Genres}\n\n**📀 Votes:** {votes}\n\n🌟 **IMDB Rating :** {Rating}\n\n📆 **Released:**  {Year} \n\n📣 **BoxOffice:** {BoxOffice}\n\n**🧑‍💻 Writer:** {writer}\n\n**🕺 Director:** {director}\n\n🗺️ **Countries:** {Countries}\n\n{caption_text}", reply_markup=InlineKeyboardMarkup(buttons))
                        await asyncio.sleep(FILTER_DEL_SECOND)
                        await remove.delete()
                else:
                    try:
                        remove = await update.reply_photo(photo=random.choice(PICS), caption=f"**👨‍🦱 Requested By:** {mention}\n\n**🤵‍♂️ Requested Name:** {query}\n\n🎥 **Movie Title:** {movie_title}\n\n🎭 **Genres:** {Genres}\n\n**📀 Votes:** {votes}\n\n🌟 **IMDB Rating :** {Rating}\n\n📆 **Released:**  {Year} \n\n📣 **BoxOffice:** {BoxOffice}\n\n**🧑‍💻 Writer:** {writer}\n\n**🕺 Director:** {director}\n\n🗺️ **Countries:** {Countries}\n\n{caption_text}", reply_markup=InlineKeyboardMarkup(buttons))
                        await asyncio.sleep(FILTER_DEL_SECOND)
                        await remove.delete()
                    except:
                        remove = await update.reply_photo(photo=random.choice(PICS), caption=f"**🏵️ Requested By:** {mention}\n**🤶 Requested Name:** {query}\n ©️ {group_name}\n\n{caption_text}", reply_markup=InlineKeyboardMarkup(buttons))
                        await asyncio.sleep(FILTER_DEL_SECOND)
                        await remove.delete()
            except:
                mention=update.from_user.mention
                query=search
                greeting=None
                group_name = f"[{update.chat.title}](t.me/{update.chat.username})" or f"[{update.chat.title}](t.me/{update.from_user.username})"
                remove = await update.reply_photo(photo=random.choice(PICS), caption=f"**🤶 Requested By:** {mention}\n**🧜 Requested Name:** {query}\n™ {group_name}", reply_markup=InlineKeyboardMarkup(buttons))
                await asyncio.sleep(FILTER_DEL_SECOND)
                await remove.delete()
            return

        data = temp.BUTTONS[keyword]
        buttons = data['buttons'][0].copy()
   
        buttons.append([InlineKeyboardButton(f"📃 1/{data['total']}",callback_data="pages"),
                        InlineKeyboardButton("🗑️", callback_data="close"),
                        InlineKeyboardButton("➡",callback_data=f"nextgroup_0_{keyword}")])

        buttons.append([InlineKeyboardButton("🤖 𝙲𝙷𝙴𝙲𝙺 𝙼𝚈 𝙿𝙼 🤖", url=f"https://telegram.dog/{temp.Bot_Username}")])

        try:             
            if settings["photo"]:
                movie_name = update.text
                movie_info = get_movie_info(movie_name)
                if movie_info:
                    poster = movie_info["pimage"]
                try:
                    query = search
                    movie_title = movie_info['title']
                    Rating = movie_info['imdb_rating']
                    Year = movie_info['release']
                    Genres = movie_info['genre']
                    Runtime = movie_info['duration']
                    Countries = movie_info['country']
                    director = movie_info['director']
                    writer = movie_info['writer']
                    language = movie_info['language']
                    votes = movie_info['votes']
                    BoxOffice = movie_info['BoxOffice']
                    mention = update.from_user.mention
                    greeting = None
                    remove = await update.reply_photo(photo=poster, caption=f"**👨‍🦱 Requested By:** {mention}\n\n**🤵‍♂️ Requested Name:** {query}\n\n🎥 **Movie Title:** {movie_title}\n\n🎭 **Genres:** {Genres}\n\n**📀 Votes:** {votes}\n\n🌟 **IMDB Rating :** {Rating}\n\n📆 **Released:**  {Year} \n\n📣 **BoxOffice:** {BoxOffice}\n\n**🧑‍💻 Writer:** {writer}\n\n**🕺 Director:** {director}\n\n🗺️ **Countries:** {Countries}\n\n{caption_text}", reply_markup=InlineKeyboardMarkup(buttons))
                    await asyncio.sleep(FILTER_DEL_SECOND)
                    await remove.delete()
                except:
                    remove = await update.reply_photo(photo=poster, caption=f"**👨‍🦱 Requested By:** {mention}\n\n**🤵‍♂️ Requested Name:** {query}\n\n🎥 **Movie Title:** {movie_title}\n\n🎭 **Genres:** {Genres}\n\n**📀 Votes:** {votes}\n\n🌟 **IMDB Rating :** {Rating}\n\n📆 **Released:**  {Year} \n\n📣 **BoxOffice:** {BoxOffice}\n\n**🧑‍💻 Writer:** {writer}\n\n**🕺 Director:** {director}\n\n🗺️ **Countries:** {Countries}\n\n{caption_text}\n\n{caption_text}", reply_markup=InlineKeyboardMarkup(buttons))
                    await asyncio.sleep(FILTER_DEL_SECOND)
                    await remove.delete()
            else:
                try:
                    remove = await update.reply_photo(photo=poster, caption=f"**👨‍🦱 Requested By:** {mention}\n\n**🤵‍♂️ Requested Name:** {query}\n\n🎥 **Movie Title:** {movie_title}\n\n🎭 **Genres:** {Genres}\n\n**📀 Votes:** {votes}\n\n🌟 **IMDB Rating :** {Rating}\n\n📆 **Released:**  {Year} \n\n📣 **BoxOffice:** {BoxOffice}\n\n**🧑‍💻 Writer:** {writer}\n\n**🕺 Director:** {director}\n\n🗺️ **Countries:** {Countries}\n\n{caption_text}", reply_markup=InlineKeyboardMarkup(buttons))
                    await asyncio.sleep(FILTER_DEL_SECOND)
                    await remove.delete()
                except :
                    remove = await update.reply_photo(photo=poster, caption=f"**👨‍🦱 Requested By:** {mention}\n\n**🤵‍♂️ Requested Name:** {query}\n\n{caption_text}", reply_markup=InlineKeyboardMarkup(buttons))
                    await asyncio.sleep(FILTER_DEL_SECOND)
                    await remove.delete()
        except:
            remove = await update.reply_photo(photo=random.choice(PICS), caption=MOVIE_TEXTZ.format(mention=update.from_user.mention, query=search, greeting=None, group_name = f"[{update.chat.title}](t.me/{update.chat.username})" or f"[{update.chat.title}](t.me/{update.from_user.username})"), reply_markup=InlineKeyboardMarkup(buttons))
            await asyncio.sleep(FILTER_DEL_SECOND)
            await remove.delete()



# Bot By https://t.me/DKBOTZ || https://t.me/DK_BOTZ || https://t.me/DKBOTZHELP
# Creadit To My Friend https://t.me/Bot_Magic_World


START_MESSAGE = """
👋Hello {mention}..!
It's Power Full [{name}](t.me/{username}) Here 😎
Add Me To Your Group And Make Sure I'm an Admin There..!
And Enjoy My Pever Show..! 🤪"""

HELP_MESSAGE = """
𝙷𝙴𝙻𝙻𝙾 {mention}
𝙸 𝙲𝙰𝙽 𝙶𝚄𝙸𝙳𝙴 𝚈𝙾𝚄 𝚃𝙷𝚁𝙾𝚄𝙶𝙷 𝙰𝙻𝙻 𝙾𝙵𝙵 [{name}](https://t.me/{username})', 𝙲𝙾𝙾𝙻 𝙵𝙴𝙰𝚃𝚄𝚁𝙴𝚂 𝙰𝙽𝙳 𝙷𝙾𝚆 𝚃𝙾 𝙿𝚁𝙾𝙿𝙴𝚁𝙻𝚈 𝚄𝚂𝙴 𝚃𝙷𝙴𝙼. 𝚃𝙷𝙴 𝙱𝚄𝚃𝚃𝙾𝙽𝚂 𝙱𝙴𝙻𝙾𝚆 𝚃𝙾 𝙽𝙰𝚅𝙸𝙶𝙰𝚃𝙴 𝚃𝙷𝙴𝙾𝚄𝙶𝙷 𝙰𝙻𝙻 𝙾𝙵 𝚃𝙷𝙴 𝙼𝙾𝙳𝚄𝙻𝙴𝚂
"""

ABOUT_MESSAGE = """
𝙱𝙾𝚃 𝚃𝚈𝙿𝙴 : -
𝙱𝙾𝚃 𝙱𝚁𝙰𝙽𝙲𝙷 : -
𝙳𝙴𝚅𝙴𝙻𝙾𝙿𝙴𝚁 : -
𝙲𝚁𝙴𝙰𝚃𝙾𝚁 : [{name}](https://t.me/{username})
𝙻𝙰𝙽𝙶𝚄𝙰𝙶𝙴 : 𝙿𝚈𝚃𝙷𝙾𝙽3 : {py3_version}
𝙻𝙸𝙱𝚁𝙰𝚁𝚈 : 𝙿𝚈𝚁𝙾𝙶𝚁𝙰𝙼 : {pyro_version}
𝚅𝙴𝚁𝚂𝙸𝙾𝙽 : {version}
𝚂𝙾𝚄𝚁𝙲𝙴 : -
"""

SETTINGS_MESSAGE = """
**𝙲𝙷𝙰𝙽𝙶𝙴 𝚈𝙾𝚄𝚁 𝚂𝙴𝚃𝚃𝙸𝙽𝙶𝚂 𝙵𝙾𝚁 Change {title} 𝙰𝚂 𝚈𝙾𝚄𝚁 𝚆𝙸𝚂𝙷.⚙"""

CHAT_LOGS_MESSAGE = """
• **{title}**\n• `{id}`\n• **{join}**"""

SPELLMODE_MESSAGE = """
**__Hello 👋 {mention}**__
**__Couldn't Find {query} ?  Please Click Your Request Name**__"""

REQUEST_MESSAGE = """
**Requested By:** {mention}\n**Requested Name:** {query}\n™ {group_name}"""

WELCOME_MESSAGE = """
𝙷𝙴𝙻𝙻𝙾 {mention} 𝚆𝙴𝙻𝙲𝙾𝙼𝙴 𝚃𝙾 {group_name}"""

FILECAPTION_MESSAGE = """
• `{file_name}` \n 𝙹𝙾𝙸𝙽 : @DKBOTZ"""

ADMIN_CMD_MESSAGE = """
𝙰𝙳𝙼𝙸𝙽𝚂 𝙲𝙾𝙼𝙼𝙰𝙽𝙳𝚂 :-
\n • /broadcast : 𝚁𝙴𝙿𝙻𝚈 𝙰𝙽𝚃 𝙼𝙴𝙳𝙸𝙰/𝙼𝚂𝙶\n • /total : 𝙶𝙴𝚃 𝙵𝙸𝙻𝙴𝚂 𝙲𝙾𝚄𝙽𝚃\n • /delete : 𝙳𝙴𝙻𝙴𝚃𝙴 𝚂𝙸𝙽𝙶𝙻𝙴 𝙵𝙸𝙻𝙴𝚂\n • /delall : 𝙳𝙴𝙻𝙴𝚃𝙴 𝙰𝙻𝙻 𝙵𝙸𝙻𝙴𝚂\n • /logs : 𝙶𝙴𝚃 𝙱𝙾𝚃 𝙻𝙾𝙶𝚂"""

STATUS_MESSAGE = """
× {bot_name} 𝚂𝚃𝙰𝚃𝚄𝚂 :-
× 𝚃𝙾𝚃𝙰𝙻 𝚄𝚂𝙴𝚁𝚂 : {users}\n× 𝚃𝙾𝚃𝙰𝙻 𝙵𝙸𝙻𝙴𝚂 : {files}\n× 𝚃𝙾𝚃𝙰𝙻 𝙲𝙷𝙰𝚃𝚂 : {chats}"""

GETFILE_TEXT = """
𝙷𝙴𝚈 {mention} 𝚈𝙾𝚄𝚁 𝙵𝙸𝙻𝙴 𝙸𝚂 𝚁𝙴𝙰𝙳𝚈
\n𝙵𝙸𝙻𝙴𝙽𝙰𝙼𝙴 : `{file_name}`\n\n𝙵𝙸𝙻𝙴𝚂𝙸𝚉𝙴 : {file_size}"""

NOT_SUB = """
𝙸 𝙻𝙸𝙺𝙴 𝚈𝙾𝚄𝚁 𝚂𝙼𝙰𝚁𝚃𝙽𝙴𝚂𝚂, 𝙱𝚄𝚃 𝙳𝙾𝙽'𝚃 𝙱𝙴 𝙾𝚅𝙴𝚁𝚂𝙼𝙰𝚁𝚃 😤.\n 𝙵𝚒𝚛𝚜𝚝 𝚂𝚞𝚋𝚜𝚌𝚛𝚒𝚋𝚎 𝙼𝚢 𝙲𝚑𝚊𝚗𝚗𝚎𝚕 😕"""              

USAGE_MESSAGE = """
🤠 🄷🄾🅆 🅃🄾 🅄🅂🄴

-

× 𝚃𝙷𝙸𝚂 𝙱𝙾𝚃 𝙳𝙴𝙿𝙻𝙾𝚈𝙴𝙳 𝙱𝚈
  - [{}](t.me/{})"""



